* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Setup in SAP LeanIX](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix)
  * Aggregation and Linkage of Software Records
